Learn R Programming

climwin (version 0.1.2)

plotbetas: Plot model beta estimates

Description

Create colour plots of model beta estimates. Will include quadratic and cubic beta estimates where appropriate.

Usage

plotbetas(dataset, plotallenv, plotall = FALSE)

Arguments

dataset
A dataframe containing information on all fitted climate windows. Output from climatewin.
plotallenv
Used in conjunction with function plotall. Should not be changed manually.
plotall
Used in conjunction with function plotall. Should not be changed manually.

Value

  • Returns colour plots of model beta estimates. Where applicable, 2nd order coefficients (quadratic) and 3rd order coefficients (cubic) will be plotted seperately.

Examples

Run this code
# Plot model beta estimates for linear models in the Mass dataset

data(MassOutput)

plotbetas(dataset = MassOutput)

Run the code above in your browser using DataLab