Learn R Programming

climwin (version 0.1.2)

plotdelta: Plot deltaAICc of models

Description

Create a colour plot of model deltaAICc values.

Usage

plotdelta(dataset)

Arguments

dataset
A dataframe containing information on all fitted climate windows. Output from climatewin.

Value

  • Returns a colour plot of model deltaAICc values (larger negative values indicate stronger models). DeltaAICc is the difference between AICc of each climate window and a null model.

Examples

Run this code
# Plot deltaAICc estimates for climate windows in the Mass dataset

data(MassOutput)

plotdelta(dataset = MassOutput)

Run the code above in your browser using DataLab