Learn R Programming

climwin (version 0.1.2)

plothist: Create a histogram of deltaAICc values

Description

Create a histogram of deltaAICc values for all fitted climate windows. Compare with randomised data if provided.

Usage

plothist(dataset, datasetrand = NULL, histq = 0.99)

Arguments

dataset
A dataframe containing information on all fitted climate windows. Output from climatewin.
datasetrand
A dataframe containing information on all fitted climate windows using randomised data. Output from randwin.
histq
If datasetrand is provided. The quantile of the randomised data that will be compared to non-randomised data. Used to determine the likelihood of finding a climate window model of a given deltaAICc value at random.

Value

  • If datasetrand is provided, plothist will return two stacked histograms to compare the deltaAICc of non-randomised and randomised data. This can help determine the likelihood of obtaining a deltaAICc value of fitted climate windows at random. Without datasetrand, plotall will create a single histogram of deltaAICc values for all fitted climate windows.

Examples

Run this code
# Plot real and randomised data for the Mass dataset

data(MassOutput)
data(MassRand)

plothist(dataset = MassOutput, datasetrand = MassRand, histq = 0.95)

# Plot deltaAICc when no randomised data is provided

data(MassOutput)

plothist(dataset = MassOutput)

Run the code above in your browser using DataLab