A dataframe containing information on all fitted climate
windows. Output from climatewin.
cw1,cw2,cw3
Cumulative weight levels used to visualise model weight
distribution. Cumulative weights represent the chance that the best model is
contained within a set. For example, there is a 95 percent chance that the best
climate window model is contained withi
Value
Returns a plot showing the distribution of cumulative model
weights. Levels determined by parameters cw1,cw2 and cw3.