Learn R Programming

climwin (version 0.1.2)

plotwin: Plot the opening and closing point of best climate windows

Description

Visualise the opening and closing point for a subset of best climate windows.

Usage

plotwin(dataset, cw = 0.95)

Arguments

dataset
A dataframe containing information on all fitted climate windows. Output from climatewin.
cw
Cumulative model weight used to subset the group of best models.

Value

  • Creates two boxplots showing the opening and closing point for a subset of best climate windows. Best climate windows make up the cumulative model weight equivalent to the value of cw.

Examples

Run this code
# View window limits for climate windows in the top 95\% of model weights.

data(MassOutput)

plotwin(dataset = MassOutput, cw = 0.95)

Run the code above in your browser using DataLab