explore: Visualise the weight distribution for given parameter values
Description
Create a plot of the weibell or generalised extreme values (GEV) distribution
for given values of shape, scale and location parameters. Used to determine
initial parameter values for weightwin.
A parameter that determines the shape of the distribution.
Should be greater than 0.
scale
A parameter that determines the scale of the distribution.
Should be greater than 0.
loc
A parameter that determines the location of the distribution.
Should be less than or equal to 0.
weightfunc
Choose whether to use a weibull ("W") or GEV ("G")
distribution.
Value
ExploreWeight will return an example plot of the distribution using
given parameter values. This can be used to select the initial parameter
values for weightwin